@@ -31,10 +31,10 @@
 # define TARGET_RISCV_ATTRIBUTE 1
 #endif
 #ifndef TARGET_RISCV_DEFAULT_ARCH
-# define TARGET_RISCV_DEFAULT_ARCH rv32imafdc_zicbom_zicbop_zicboz_zicond_zicsr_zifencei_zmmul_zba_zbb_zbc_zbs
+# define TARGET_RISCV_DEFAULT_ARCH rv64imafdc_zicbom_zicbop_zicboz_zicond_zicsr_zifencei_zmmul_zba_zbb_zbc_zbs
 #endif
 #ifndef TARGET_RISCV_DEFAULT_ABI
-# define TARGET_RISCV_DEFAULT_ABI ilp32d
+# define TARGET_RISCV_DEFAULT_ABI lp64d
 #endif
 #ifdef IN_GCC
 # include "options.h"
